@@ -3,4 +3,4 @@ from __future__ import absolute_import
 # flake8: noqa
 
 # import apis into api package
-from hubspot.crm.owners.api.default_api import DefaultApi
+from hubspot.crm.owners.api.owners_api import OwnersApi
