@@ -4,7 +4,7 @@ from ...discovery_base import DiscoveryBase
 
 class Discovery(DiscoveryBase):
     @property
-    def сallbacks_api(self) -> api_client.CallbacksApi:
+    def callbacks_api(self) -> api_client.CallbacksApi:
         return self._configure_api_client(api_client, "CallbacksApi")
 
     @property
