@@ -5,8 +5,8 @@ from ...discovery_base import DiscoveryBase
 
 class Discovery(DiscoveryBase):
     @property
-    def default_api(self) -> api_client.DefaultApi:
-        return self._configure_api_client(api_client, "DefaultApi")
+    def owners_api(self) -> api_client.OwnersApi:
+        return self._configure_api_client(api_client, "OwnersApi")
 
     def get_all(self, **kwargs):
-        return fetch_all(self.default_api, **kwargs)
+        return fetch_all(self.owners_api, **kwargs)
